==> reactstrap-react-lib-cli-1.0.4.tgz: package/src/index.ts <==
#!/usr/bin/env node
import inquirer from "inquirer"
import fs from "fs"
import path from "path"
import Rx from "rxjs"
let buf:string;

inquirer.prompt([
  {
      type : "list",
      message : "Choose Language",
      name : "language",
      choices : ["Typescript"]
      // choices : ["Typescript", "Javascript"]
  },
  {
   type : "list",
   message : "Choose Form",
   name : "form",
   choices : ["FormSubmit"]
  //  choices : ["FormSubmit", "FormDelete", "Table", "Admin Panel"]
}
]).then(answer=>{

   let filepath:string
    if(answer.language == 'Typescript' && answer.form=='FormSubmit' ){
        filepath = path.resolve(__dirname, "../src/assets/typescript/FormSubmit.tsx")
        buf = fs.readFileSync(filepath).toString();

      // wrun inque=re here
      inquirer.prompt([
        {
          "type" : "input",
          "name" : "FormName",
          "message" : "Name of the component"
        }
    ]).then(ans=>{
        buf = buf.replace(`Example`, ans.FormName)
       inputLoop("", "",buf)
}).catch(err=> console.log(err))
    }//if(answer.language == 'Typescript' && answer.form=='FormSubmit' )

})





const inputLoop =  (inputStr:string, interfaceString:string, buf:string):void=>{

    inquirer.prompt([{
      "type" : "input",
      "name" : `field`
    },
    {
      "type" : "list",
      "name" : "InputType",
      "choices" : [
      'text',
      'number',
      'email',
      'password',
      'select',
      'file',
      'radio',
      'checkbox',
      'textarea',
      'date',
      'datetime-local',
      'hidden',
      'image',
      'month',
      'range',
      'search',
      'tel',
      'url',
      'week',
      'datetime',
      'time',
      'color',

     ]
    },
    
    {
      "type" : "list",
      "name" : "continue",
      "message" : "Should we continue to add more fields?",
      "choices" : ["Yes", "No"]
    }
    
  ]).then(ans=>{
    inputStr = `${inputStr}
    <Col sm={12} md={6} lg={3}>
      <FormGroup>
          <Label>${ans.field}</Label>
          <Input type="${ans.InputType}" 
          value={inputObj.${ans.field}} 
          onChange={(e)=>setInputObj({...inputObj, ${ans.field} :${createInterFace(ans.InputType) == "number" ? 'parseInt(e.target.value)' : 'e.target.value'} })}
 
      />
      </FormGroup>
    </Col>
    `

    interfaceString = `${interfaceString}  ${ans.field} : ${createInterFace(ans.InputType)};`
    if(ans.continue == "Yes"){
      inputLoop(inputStr, interfaceString,buf)
    }else{
      buf = buf.replace(`<><Row></Row></>`, `
      <>
        <Row> 
          ${inputStr}
        </Row>
      </>`)

      buf = buf.replace(`interface FORM{name:string}`, `interface FORM{${interfaceString}}` )

      fs.writeFileSync("Form.tsx", buf);
    }
    
})//end of then

}


const createInterFace = (inputType:string):string=>{
  let cur:any = {
    'text'              :  "string"      ,
    'number'            :  "number"      ,
    'email'             :  "string"      ,
    'password'          :  "string"      ,
    'select'            :  "any"         ,
    'file'              :  "any"         ,
    'radio'             :  "any"         ,
    'checkbox'          :  "string"      ,
    'textarea'          :  "string"      ,
    'date'              :  "string"        ,
    'datetime-local'    :  "string"        ,
    'hidden'            :  "string"      ,
    'image'             :  "any"         ,
    'month'             :  "any"         ,
    'range'             :  "any"         ,
    'search'            :  "string"      ,
    'tel'               :  "any"         ,
    'url'               :  "string"      ,
    'week'              :  "string"      ,
    'datetime'          :  "string"      ,
    'time'              :  "string"      ,
    'color'             :  "string"      ,

  }
let ret:string="";
Object.keys(cur).forEach(el=> el==inputType ? ret = cur[el] : "")
 return ret;
}

==> reactstrap-react-lib-cli-1.0.6.tgz: package/src/index.ts <==
#!/usr/bin/env node
import inquirer from "inquirer"
import fs from "fs"
import path from "path"
import {inputLoop} from "./lib/formSubmit"
let buf:string;

inquirer.prompt([
  {
      type : "list",
      message : "Choose Language",
      name : "language",
      choices : ["Typescript"]
      // choices : ["Typescript", "Javascript"]
  },
  {
   type : "list",
   message : "Choose Form",
   name : "form",
   choices : ["FormSubmit", "Table"]
  //  choices : ["FormSubmit", "FormDelete", "Table", "Admin Panel"]
}
]).then(answer=>{

   let filepath:string
   /**
    * ============
    * FORM SUBMIT
    * ============
    */
    if(answer.language == 'Typescript' && answer.form=='FormSubmit' ){
        filepath = path.resolve(__dirname, "../src/assets/typescript/FormSubmit.tsx")
        buf = fs.readFileSync(filepath).toString();
      inquirer.prompt([
        {
          "type" : "input",
          "name" : "FormName",
          "message" : "Name of the component"
        }
      ]).then(ans=>{
      let fieldArray:string[]=[];
        buf = buf.replace(`Example`, ans.FormName)
       inputLoop("", "", "",buf, ans.FormName,fieldArray)
      }).catch(err=> console.log(err))
    }


    /**
     * ==============
     * TABLE
     * ==============
     */
    if(answer.language == 'Typescript' && answer.form=='Table' ){
      filepath = path.resolve(__dirname, "../src/assets/typescript/Table.tsx")
      buf = fs.readFileSync(filepath).toString();
      inquirer.prompt([
        {
          "type" : "input",
          "name" : "FormName",
          "message" : "Name of the component"
        }
      ]).then(ans=>{
      let fieldArray:string[]=[];
        buf = buf.replace(`Example`, ans.FormName)
        fs.writeFileSync(`${ans.FormName}.tsx`, buf);
      }).catch(err=> console.log(err))
    }



})
